# Release Notes

## 0.8.0

 * Fixed [response schema output](https://github.com/vitalik/django-ninja/issues/19)
 * Pydantic 1.7 support

## 0.7.0

 * Added [csrf](/tutorial/csrf) configuration.

## 0.6.0

 * Fixed router authentication (#20)
 
## 0.5.0

 * Responses now support querysets

## 0.4.0

 * Locked to pydantic 1.6 and with various bug fixes automatically solved

## 0.3.0

 * Added [response schema](/tutorial/response-schema) parameter.

## 0.2.0

 * Added async operations.

## 0.1.1

 * First release to public.
